@@ -41,6 +41,7 @@
 #include "xap_Module.h"
 #include "xap_App.h"
 #include "xap_Frame.h"
+#include "fp_Run.h"
 #include "fv_View.h"
 #include "ap_Menu_Id.h"
 #include "ev_Menu_Actions.h"
@@ -78,6 +79,8 @@
 #include <goffice/graph/gog-renderer-gnome-print.h>
 #include <goffice/utils/go-format.h>
 #include <gsf/gsf-impl-utils.h>
+#include <gsf/gsf-output-memory.h>
+#include <gsf/gsf-libxml.h>
 
 #include "ut_sleep.h"
 #include <sys/types.h>  
@@ -132,6 +135,7 @@ typedef struct _AbiControlGUI
 	GObject base;
 	char *object_id;
 	PD_Document * pDoc;
+	GOChartView * pView;
 };
 
 typedef struct _AbiControlGUI AbiControlGUI;
@@ -759,28 +763,33 @@ cb_update_graph (GogGraph *graph, gpointer data)
 {
 	g_return_if_fail (IS_GOG_GRAPH (graph));
 	AbiControlGUI *acg = ABI_CONTROL_GUI (data);
-	xmlDocPtr pDoc = xmlNewDoc ((xmlChar const*)"1.0");
-	xmlChar *mem;
-	int size;
+	acg->pView->SetGuru (NULL);
 	AbiGO_LocaleTransactor tn(LC_NUMERIC, "C");
 	AbiGO_LocaleTransactor tm(LC_MONETARY, "C");
-	pDoc->children = gog_object_write_xml (GOG_OBJECT (graph), pDoc);
-	xmlDocDumpMemory (pDoc, &mem, &size);
+	GsfOutput* output = gsf_output_memory_new ();
+	GsfXMLOut* xml = gsf_xml_out_new (output);
+	gog_object_write_xml_sax(GOG_OBJECT (graph), xml);
+	UT_Byte const *bytes = gsf_output_memory_get_bytes (GSF_OUTPUT_MEMORY (output));
 	UT_ByteBuf myByteBuf;
-	myByteBuf.append((UT_Byte*)mem, size);
-	XAP_Frame *pFrame = XAP_App::getApp()->getLastFocussedFrame();
-	FV_View* pView = static_cast<FV_View*>(pFrame->getCurrentView());
+	myByteBuf.append(bytes, gsf_output_size (output));
+	FV_View* pView = acg->pView->getRun ()->getBlock ()->getView ();
 
 	const char* mimetypeGOChart = "application/x-goffice-graph";
 	const char * szProps="embed-type: GOChart";
 	UT_DEBUGMSG(("Doing Embed Update from GOG callback \n"));
-	pView->cmdUpdateEmbed(&myByteBuf,mimetypeGOChart,szProps);
+	pView->cmdUpdateEmbed(acg->pView->getRun (), &myByteBuf,mimetypeGOChart,szProps);
 
-	xmlFree (mem);
-	xmlFreeDoc (pDoc);
+	g_object_unref (xml);
+	g_object_unref (output);
 	g_object_unref (acg);
 }
 
+static void
+guru_destroyed_cb (GOChartView *pView)
+{
+	pView->SetGuru (NULL);
+}
+
 bool 
 AbiGOChart_Create(AV_View* v, EV_EditMethodCallData *d)
 {
@@ -794,33 +803,34 @@ AbiGOChart_Create(AV_View* v, EV_EditMethodCallData *d)
 	
 	acg->pDoc = static_cast<PD_Document *>(pFrame->getCurrentDoc());
 
-
 	GogGraph *graph = (GogGraph *) g_object_new (GOG_GRAPH_TYPE, NULL);
 	/* by default, create one chart and add it to the graph */
 	gog_object_add_by_name (GOG_OBJECT (graph), "Chart", NULL);
-	xmlDocPtr xml = xmlNewDoc ((xmlChar const*)"1.0");
-	xmlChar *mem;
-	int size;
+	GsfOutput* output = gsf_output_memory_new ();
+	GsfXMLOut* xml = gsf_xml_out_new (output);
 	{
 		AbiGO_LocaleTransactor tn(LC_NUMERIC, "C");
 		AbiGO_LocaleTransactor tm(LC_NUMERIC, "C");
-		xml->children = gog_object_write_xml (GOG_OBJECT (graph), xml);
+		gog_object_write_xml_sax (GOG_OBJECT (graph), xml);
 	}
-	xmlDocDumpMemory (xml, &mem, &size);
-	myByteBuf.append((UT_Byte*)mem, size);
-	xmlFree (mem);
-	xmlFreeDoc (xml);
+	UT_Byte const *bytes = gsf_output_memory_get_bytes (GSF_OUTPUT_MEMORY (output));
+	myByteBuf.append(bytes, gsf_output_size (output));
 
 	const char* mimetypeGOChart = "application/x-goffice-graph";
-	const char * szProps="embed-type: GOChart; width:2.5in; height:2.5in";
+	const char * szProps="embed-type: GOChart";
 	PT_DocPosition pos = pView->getPoint();
 	pView->cmdInsertEmbed(&myByteBuf,pView->getPoint(),mimetypeGOChart,szProps);
 	pView->cmdSelect(pos,pos+1);
+	acg->pView = GR_GOChartManager::last_created_view;
 	GtkWidget *dialog = gog_guru (graph, GOG_DATA_ALLOCATOR (acg),
 		       NULL /*GO_CMD_CONTEXT (wbcg)*/, GTK_WINDOW(pFrameImpl->getTopLevelWindow()),
 		       g_cclosure_new (G_CALLBACK (cb_update_graph), acg,
 					(GClosureNotify) graph_user_config_free_data));
+	acg->pView->SetGuru (dialog);
+	g_signal_connect_swapped (G_OBJECT (dialog), "destroy", G_CALLBACK (guru_destroyed_cb), acg->pView);
 
+	g_object_unref (xml);
+	g_object_unref (output);
 	g_object_unref (G_OBJECT (graph));
 
 	return true;
@@ -862,6 +872,8 @@ const char * GR_GOChartManager::getObjectType(void) const
   return "GOChart";
 }
 
+GOChartView * GR_GOChartManager::last_created_view = NULL;
+
 void GR_GOChartManager::initialize(void)
 {
   // Load the GOChart library
@@ -872,8 +884,8 @@ void GR_GOChartManager::initialize(void)
  */ 
 UT_sint32  GR_GOChartManager::_makeGOChartView(void)
 {
-     GOChartView * pGOChartView = new GOChartView(this);
-     m_vecGOChartView.addItem(pGOChartView);
+     last_created_view = new GOChartView(this);
+     m_vecGOChartView.addItem(last_created_view);
      return static_cast<UT_sint32>(m_vecGOChartView.getItemCount()-1);
 }
 
@@ -992,7 +1004,7 @@ bool GR_GOChartManager::modify(UT_sint32 uid)
   return false;
 }
 
-bool  GR_GOChartManager::isEdittable(void)
+bool  GR_GOChartManager::isEdittable(UT_sint32 uid)
 {
   return true;
 }
@@ -1080,12 +1092,19 @@ bool GR_GOChartManager::convert(UT_uint32 iConType, UT_ByteBuf & From, UT_ByteBu
   return false;
 }
 
+void GR_GOChartManager::setRun(UT_sint32 uid, fp_Run *pRun)
+{
+	GOChartView * pGOChartView = m_vecGOChartView.getNthItem(uid);
+	pGOChartView->SetRun (pRun);
+}
+
 GOChartView::GOChartView(GR_GOChartManager * pGOMan): m_pGOMan(pGOMan)
 {
 	m_Graph = NULL;
 	m_Image = NULL;
 	m_Renderer = GOG_RENDERER (g_object_new (GOG_RENDERER_PIXBUF_TYPE, NULL));
 	width = height = 0;
+	m_Guru = NULL;
 }
 
 GOChartView::~GOChartView(void)
@@ -1095,6 +1114,8 @@ GOChartView::~GOChartView(void)
 		g_object_unref (m_Graph);
 	if (m_Image)
 		delete m_Image;
+	if (m_Guru)
+		gtk_widget_destroy (m_Guru);
 }
 
 void GOChartView::render(UT_Rect & rec)
@@ -1118,7 +1139,6 @@ void GOChartView::render(UT_Rect & rec)
 		// too).
 		//
 		y = pUGG->scale_ydir(y);
-		printf("print chart - x %d,y %d,width %d,height %d \n",x,y,myWidth,myHeight);
 		gnome_print_gsave (ctx);
 
 		gnome_print_translate (ctx, x, y+myHeight);
@@ -1127,23 +1147,26 @@ void GOChartView::render(UT_Rect & rec)
 	}
 	else 
 	{
-		GdkPixbuf *pixbuf;
-		if (rec.height != height || rec.width != width || (height == 0) || (width == 0)) 
+		GR_Graphics *pUGG = m_pGOMan->getGraphics();
+		UT_sint32 _width = pUGG->tdu(rec.width);
+		UT_sint32 _height = pUGG->tdu(rec.height);
+		UT_sint32 x = pUGG->tdu(rec.left);
+		UT_sint32 y = pUGG->tdu(rec.top);
+		if (_width != width || _height != height)
 		{
 			GdkPixbuf *pixbuf;
-			width = rec.width;
-			height = rec.height;
-			gog_renderer_pixbuf_update (GOG_RENDERER_PIXBUF (m_Renderer), width, height, 1.0);	
+			width = _width;
+			height = _height;
+			gog_renderer_pixbuf_update (GOG_RENDERER_PIXBUF (m_Renderer), _width, _height, 1.0);	
 			if (m_Image)
 				delete m_Image;
-			gsize length;
 			pixbuf = gog_renderer_pixbuf_get (GOG_RENDERER_PIXBUF (m_Renderer));
 			m_Image = new GR_UnixImage(NULL, pixbuf);
 			g_object_ref(pixbuf);
 			m_Image->scaleImageTo(m_pGOMan->getGraphics(),rec);
 		}
 		GR_Painter painter(m_pGOMan->getGraphics());
-		painter.drawImage (m_Image, rec.left, rec.top - height);
+		painter.drawImage (m_Image, rec.left, rec.top - rec.height);
 	}
 }
 
@@ -1153,7 +1176,7 @@ void GOChartView::loadBuffer(UT_UTF8String & sGOChartXML)
 		g_object_unref (m_Graph);
 	AbiGO_LocaleTransactor tn(LC_NUMERIC, "C");
 	AbiGO_LocaleTransactor tm(LC_MONETARY, "C");
-	xmlDocPtr xml = xmlParseMemory((const char*)sGOChartXML.utf8_str(), sGOChartXML.size());
+	xmlDocPtr xml = xmlParseMemory((const char*)sGOChartXML.utf8_str(), sGOChartXML.byteLength());
 	m_Graph = GOG_GRAPH (gog_object_new_from_xml (NULL, xml->children));
 	if (m_Graph)
 		g_object_set (G_OBJECT (m_Renderer), "model", m_Graph, NULL);
@@ -1173,11 +1196,14 @@ void GOChartView::modify()
 	AbiControlGUI *acg = ABI_CONTROL_GUI (g_object_new (ABI_CONTROL_GUI_TYPE, NULL));
 	
 	acg->pDoc = static_cast<PD_Document *>(pFrame->getCurrentDoc());
+	acg->pView = this;
 
-	gog_guru (m_Graph, GOG_DATA_ALLOCATOR (acg),
+	GtkWidget *dialog = gog_guru (m_Graph, GOG_DATA_ALLOCATOR (acg),
 		       NULL /*GO_CMD_CONTEXT (wbcg)*/, GTK_WINDOW(pFrameImpl->getTopLevelWindow()),
 		       g_cclosure_new (G_CALLBACK (cb_update_graph), acg,
 					(GClosureNotify) graph_user_config_free_data));
+	acg->pView->SetGuru (dialog);
+	g_signal_connect_swapped (G_OBJECT (dialog), "destroy", G_CALLBACK (guru_destroyed_cb), acg->pView);
 }
 
 static UT_uint32 GOChartManagerUID = 0; 
@@ -1212,7 +1238,9 @@ int abi_plugin_register (XAP_ModuleInfo * mi)
     XAP_App * pApp = XAP_App::getApp();	
     pGOChartManager = new GR_GOChartManager(NULL);
     GOChartManagerUID = pApp->registerEmbeddable(pGOChartManager);
-    UT_DEBUGMSG(("Class  %x created! Listener Id %d \n", GOChartManagerUID));
+	// the message below makes valgrind scream because there is only one parameter where
+	// 2 are expected. disabled.
+    xxx_UT_DEBUGMSG(("Class  %x created! Listener Id %d \n", GOChartManagerUID));
    // Add to AbiWord's menus.
     AbiGOChart_addToMenus();
  	/* Initialize libgoffice */
@@ -1225,6 +1253,10 @@ int abi_plugin_register (XAP_ModuleInfo * mi)
  	GO_DATA_SCALAR_VAL_TYPE;
 	GO_DATA_VECTOR_VAL_TYPE;
  	GO_DATA_MATRIX_VAL_TYPE;
+	/* the resolution of symbols in libgoffice must be forced because when
+	creating the guru window, libglade needs foo_canvas_new. There might
+	be a better solution..., I could not find one */
+	g_module_close (g_module_open ("libgoffice-1", (GModuleFlags)0));
    return 1;
 }
 
