@@ -45,12 +45,12 @@
 #include "ut_string.h"
 #include "../xp/AbiGrammarUtil.h"
 
-#include <LinkGrammarWrap.h>
+#include "LinkGrammarWrap.h"
 
 LinkGrammarWrap::LinkGrammarWrap(void) 
 {
   m_Opts = parse_options_create();
-  m_Dict = dictionary_create("en/4.0.dict","en/4.0.knowledge","en/4.0.constituent-knowledge","en/4.0.affix");
+  m_Dict = dictionary_create_lang("en");
   parse_options_set_max_parse_time(m_Opts, 1); // 1 second max parse time
 }
 
