@@ -95,8 +95,8 @@ keyvalue :: keyvalue (char *key, char *value)
 
 keyvalue :: ~keyvalue ()
 {
-//	delete m_key;
-//	delete m_value;
+	delete m_key;
+	delete m_value;
 }
 /*****************************************************************************/
 int docbook_coquille_register ()
@@ -124,23 +124,23 @@ int docbook_coquille_register ()
 
 	/* opens configuration file */
 	FILE *file = NULL;
-	file = fopen (
-			UT_catPathname (XAP_App::getApp () -> getUserPrivateDirectory (), "coquille.conf"),
-			"r"
-		);
-	if (!file)
-			file = fopen (
-				UT_catPathname (XAP_App::getApp () -> getAbiSuiteLibDir (), "coquille.conf"),
-			"r"
-		);
+	char *_name;
+
+	_name = UT_catPathname (XAP_App::getApp () -> getUserPrivateDirectory (), "coquille.conf");
+	file = fopen (_name,"r");
+	FREEP(_name);
+	if (!file) {
+		_name = UT_catPathname (XAP_App::getApp () -> getAbiSuiteLibDir (), "coquille.conf");
+		file = fopen (_name,"r");
+		FREEP(_name);
+	}
 	if (!file)
 	{
 		/* not our days: the file doesn't exist :( */
 		/* ok, let's create it =) */
-		file = fopen (
-			UT_catPathname (XAP_App::getApp () -> getUserPrivateDirectory (), "coquille.conf"),
-			"w+"
-		);
+		_name = UT_catPathname (XAP_App::getApp () -> getUserPrivateDirectory (), "coquille.conf");
+		file = fopen (_name, "w+");
+		FREEP(_name);
 		if (file)
 		{
 		  fprintf (file, "coq-title=\n");
@@ -150,11 +150,9 @@ int docbook_coquille_register ()
 		  fprintf (file, "coq-codaff=\n");
 		  fclose (file);
 		}
-		file = fopen (
-			UT_catPathname (XAP_App::getApp () -> getUserPrivateDirectory (), "coquille.conf"),
-			"r"
-		);
-
+		_name = UT_catPathname (XAP_App::getApp () -> getUserPrivateDirectory (), "coquille.conf");
+		file = fopen (_name, "r");
+		FREEP(_name);
 	}
 
 	if (file)
@@ -186,6 +184,8 @@ int docbook_coquille_unregister ()
 {
 //	UT_ASSERT (m_impCSniffer);
 //	UT_ASSERT (m_expCSniffer);
+  
+        UT_VECTOR_PURGEALL (keyvalue *, header_values);
 
 	IE_Imp::unregisterImporter (m_impCSniffer);
 	if (!m_impCSniffer->unref())
