@@ -239,7 +239,7 @@ void streamRead(GsfInput* aStream, TextAttr& aAttr, gsf_off_t aEoa) UT_THROWS((U
 			UT_uint16 fontLen = GSF_LE_GET_GUINT16(aAttr.data + 3);
 			UT_String_sprintf(aAttr.attrVal, "%.*s", fontLen, (aAttr.data + 5));
 			
-			break; }
+		break; }
     case 0x1007: // font height
       // structure: | height (2 byte, twips) | prop (?) (2 byte) (if version >= 2, if ver=1 1 byte) | unit (if version>=2) |
       // XXX we ignore "prop" and unit for now, they seem not used much
@@ -928,7 +928,9 @@ UT_Error IE_Imp_StarOffice::importFile(const char* szFilename) UT_THROWS(()) {
 						UT_DEBUGMSG(("SDW: StringPool: found 0x%04x <-> %.*s\n", id, len, str));
 						UT_UCS4Char* convertedString = reinterpret_cast<UT_UCS4Char*>(UT_convert_cd(str, len, cd, NULL, NULL));
 						mStringPool.insert(id, convertedString);
+                        delete [] str;
 					}
+                    UT_iconv_close(cd);
 					break;
 				}
 				case SWG_COMMENT: // skip over comments
